@@ -9,7 +9,7 @@
 #include <QXmlStreamReader>
 #include <QPixmap>
 #include <QNetworkReply>
-#include <QNetworkConfigurationManager>
+#include <QNetworkAccessManager>
 
 #include "eveskilltraining.h"
 class EveCharacter : public QObject
